@@ -238,3 +238,49 @@ class Identity(Service):
             },
             method='POST'
         )
+
+    def create_device_flow_authorization(self, code_challenge, code_challenge_method='s256'):
+        """ POST /tokens/device Creates a new request for a device flow authorization
+
+            code_challenge: str
+                Code challenge for the request. This should be generated by the client.
+            code_challenge_method: str
+                Code challenge method. Currently only supports 's256'
+        """
+        endpoint = '/api/v1/tokens/device'
+        return self.fetch(
+            auth=HTTPBasicAuth(username=self.sws.app_id, password=self.sws.secret),
+            endpoint=endpoint,
+            body={
+                'code_challenge': code_challenge,
+                'code_challenge_method': code_challenge_method
+            },
+            method='POST',
+            headers={
+                'Accept': 'application/json',
+                'Content-Type': 'application/x-www-form-urlencoded'
+            }
+        )
+
+    def exchange_device_code_for_tokens(self, device_code, code_verifier):
+        """ POST /tokens/device/code Exchanges a device code for access/refresh tokens
+
+            device_code: str
+                Device code for the authorization request.
+            code_verifier: str
+                Corresponding code verifier to the code challenge.
+        """
+        endpoint = '/api/v1/tokens/device'
+        return self.fetch(
+            auth=HTTPBasicAuth(username=self.sws.app_id, password=self.sws.secret),
+            endpoint=endpoint,
+            body={
+                'device_code': device_code,
+                'code_verifier': code_verifier
+            },
+            method='POST',
+            headers={
+                'Accept': 'application/json',
+                'Content-Type': 'application/x-www-form-urlencoded'
+            }
+        )
